@@ -46,7 +46,7 @@ typedef enum {
 
 typedef struct _PropertyDialog {
 	GtkWidget *dialog;
-	
+
 	GtkWidget *no_info;
 	GtkWidget *real_info;
 	GtkWidget *specific_info;
@@ -59,7 +59,7 @@ typedef struct _PropertyDialog {
 	GtkWidget *freedb_box;
 	GtkWidget *freedb_server;
 	GtkWidget *update;
-	
+
 	GtkWidget *other_server;
 	GtkWidget *other_box;
 	GtkWidget *other_host;
@@ -71,7 +71,9 @@ typedef struct _PropertyDialog {
 	GTcpSocket *socket;
 	GIOChannel *iochannel;
 	guint tag;
-
+	/* Gconf notify ID */
+	guint notify_id;
+	
 	ConnectionMode mode;
 	CDDBSlaveAccess access;
 } PropertyDialog;
@@ -88,10 +90,26 @@ enum {
 	CDDB_OTHER_SERVER
 };
 
+/* Taken from cddb-slave2's main.c */
+static char *
+get_hostname (void)
+{
+	char name[4096];
+
+	if (gethostname (name, 4095) == -1) {
+		return g_strdup ("localhost");
+	} else {
+		return g_strdup (name);
+	}
+}
+
 static void
 destroy_window (GtkWidget *window,
 		PropertyDialog *pd)
 {
+	/* Remove the gconf notify */
+	gconf_client_notify_remove (client, pd->notify_id);
+	
 	g_free (pd);
 	gtk_main_quit ();
 }
@@ -104,7 +122,7 @@ dialog_button_clicked_cb (GtkDialog *dialog,
 	switch (response_id) {
 	case GTK_RESPONSE_HELP:
 		gnome_help_display_desktop (NULL, "user-guide",
-					    "wgoscustlookandfeel.xml",
+					    "user-guide.xml",
 					    "goscustlookandfeel-39", &error);
 		if (error) {
 			GtkWidget *msg_dialog;
@@ -139,6 +157,8 @@ no_info_toggled (GtkToggleButton *tb,
 
 	gtk_widget_set_sensitive (pd->name_box, FALSE);
 	gconf_client_set_int (client, "/apps/CDDB-Slave2/info", CDDB_SEND_FAKE_INFO, NULL);
+	gtk_entry_set_text (GTK_ENTRY (pd->real_name), "");
+	gtk_entry_set_text (GTK_ENTRY (pd->real_host), "");
 }
 
 static void
@@ -151,6 +171,8 @@ real_info_toggled (GtkToggleButton *tb,
 
 	gtk_widget_set_sensitive (pd->name_box, FALSE);
 	gconf_client_set_int (client, "/apps/CDDB-Slave2/info", CDDB_SEND_REAL_INFO, NULL);
+	gtk_entry_set_text (GTK_ENTRY (pd->real_name),g_get_user_name());
+	gtk_entry_set_text (GTK_ENTRY (pd->real_host),get_hostname());
 }
 
 static void
@@ -203,6 +225,9 @@ static void
 other_freedb_toggled (GtkToggleButton *tb,
 		      PropertyDialog *pd)
 {
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GtkTreeSelection *selection;
 	if (gtk_toggle_button_get_active (tb) == FALSE) {
 		return;
 	}
@@ -211,7 +236,17 @@ other_freedb_toggled (GtkToggleButton *tb,
 	gtk_widget_set_sensitive (pd->other_box, FALSE);
 
 	gconf_client_set_int (client, "/apps/CDDB-Slave2/server-type", CDDB_OTHER_FREEDB, NULL);
-	/* Set it to the default selection */
+	/* Set the selection */
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (pd->freedb_server));
+
+	if (gtk_tree_selection_get_selected (selection, &model, &iter) == TRUE) {
+		char *server;
+		char *port;
+		
+		gtk_tree_model_get (model, &iter, 0, &server, 1, &port, -1);
+		gconf_client_set_string (client, "/apps/CDDB-Slave2/server", server, NULL);
+		gconf_client_set_int (client, "/apps/CDDB-Slave2/port", atoi (port), NULL);
+	}
 }
 
 static void
@@ -219,7 +254,7 @@ other_server_toggled (GtkToggleButton *tb,
 		      PropertyDialog *pd)
 {
 	const char *str;
-	
+
 	if (gtk_toggle_button_get_active (tb) == FALSE) {
 		return;
 	}
@@ -263,7 +298,7 @@ do_goodbye (PropertyDialog *pd)
 {
 	guint bytes_writen;
 	GIOError status;
-	
+
 	status = gnet_io_channel_writen (pd->iochannel, "quit\n",
 					 5, &bytes_writen);
 	pd->mode = CONNECTION_MODE_NEED_GOODBYE;
@@ -298,7 +333,7 @@ do_goodbye_response (PropertyDialog *pd,
 
 	pd->mode = CONNECTION_MODE_NEED_HELLO;
 	gtk_widget_set_sensitive (pd->update, TRUE);
-	
+
 	return FALSE;
 }
 
@@ -315,7 +350,7 @@ do_sites_response (PropertyDialog *pd,
 	} else {
 		code = atoi (response);
 	}
-	
+
 	switch (code) {
 	case 210:
 		if (response[0] == '.') {
@@ -335,7 +370,7 @@ do_sites_response (PropertyDialog *pd,
 			if (end != NULL) {
 				*end = 0;
 			}
-			
+
 			vector = g_strsplit (res, " ", 5);
 			g_free (res);
 			if (vector == NULL) {
@@ -372,7 +407,7 @@ do_sites_response (PropertyDialog *pd,
 	}
 	return more;
 }
-	
+
 static void
 do_sites (PropertyDialog *pd)
 {
@@ -506,14 +541,14 @@ read_from_server (GIOChannel *iochannel,
 	}
 
 	if (condition & (G_IO_IN | G_IO_PRI)) {
-		GIOError error;
+		GIOStatus status;
 		char *buffer;
 		gsize bytes_read;
 
 		/* Read the data into our buffer */
-		error = g_io_channel_read_line (iochannel, &buffer,
+		status = g_io_channel_read_line (iochannel, &buffer,
 						&bytes_read, NULL, NULL);
-		while (error == G_IO_STATUS_NORMAL) {
+		while (status == G_IO_STATUS_NORMAL) {
 			gboolean more = FALSE;
 
 			switch (pd->mode) {
@@ -528,7 +563,7 @@ read_from_server (GIOChannel *iochannel,
 			case CONNECTION_MODE_NEED_SITES_RESPONSE:
 				more = do_sites_response (pd, buffer);
 				break;
-				
+
 			case CONNECTION_MODE_NEED_GOODBYE:
 				more = do_goodbye_response (pd, buffer);
 				break;
@@ -542,7 +577,7 @@ read_from_server (GIOChannel *iochannel,
 			g_free (buffer);
 
 			if (more == TRUE) {
-				error = g_io_channel_read_line (iochannel, &buffer,
+				status = g_io_channel_read_line (iochannel, &buffer,
 								&bytes_read, NULL, NULL);
 			} else {
 				break;
@@ -586,12 +621,12 @@ update_clicked (GtkButton *update,
 {
 	GTcpSocketConnectAsyncID *sock;
 	GtkTreeIter iter;
-	
+
 	/* Clear the list and put the default there */
 	gtk_list_store_clear (GTK_LIST_STORE (pd->model));
 	gtk_list_store_append (GTK_LIST_STORE (pd->model), &iter);
 	gtk_list_store_set (GTK_LIST_STORE (pd->model), &iter, 0, "freedb.freedb.org", 1, "888", 2, "Random server", -1);
-	
+
 	gtk_widget_set_sensitive (pd->update, FALSE);
 	/* Should use the gconf values */
 	sock = gnet_tcp_socket_connect_async ("freedb.freedb.org", 888,
@@ -633,33 +668,100 @@ make_tree_model (void)
 	return GTK_TREE_MODEL (store);
 }
 
-static GtkWidget *
-hig_category_new (GtkWidget *parent, gchar *title, gboolean expand, gboolean fill)
+static void
+notify_cb (GConfClient *client,
+		guint cnxn_id,
+		GConfEntry *entry,
+		gpointer user_data)
 {
-	GtkWidget *vbox, *vbox2, *hbox;
-	GtkWidget *label;
-	gchar *tmp;
-	
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (parent), vbox, expand, fill, 0);
+	PropertyDialog *pd = user_data;
+	char *str;
+	const char *entry_str;
+	int info;
 
-	tmp = g_strdup_printf ("<b>%s</b>", _(title));
-	label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_markup (GTK_LABEL (label), tmp);
-	g_free (tmp);
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	if (!strcmp (entry->key, "/apps/CDDB-Slave2/name")) {
+		str = gconf_client_get_string (client, "/apps/CDDB-Slave2/name", NULL);
+		entry_str = gtk_entry_get_text (GTK_ENTRY (pd->real_name));
 
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
+		if (str != NULL && strcmp (str, entry_str) != 0) {
+			g_signal_handlers_block_by_func	(G_OBJECT (pd->real_name), G_CALLBACK (real_name_changed), pd);
+			gtk_entry_set_text (GTK_ENTRY (pd->real_name), str);
+			g_signal_handlers_unblock_by_func (G_OBJECT (pd->real_name), G_CALLBACK (real_name_changed), pd);
+		}
 
-	label = gtk_label_new ("    ");
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+		if (str) g_free (str);
+	} else if (!strcmp (entry->key, "/apps/CDDB-Slave2/hostname")) {
+		str = gconf_client_get_string (client, "/apps/CDDB-Slave2/hostname", NULL);
+		entry_str = gtk_entry_get_text (GTK_ENTRY (pd->real_host));
 
-	vbox2 = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
+		if (str != NULL && strcmp (str, entry_str) != 0) {
+			g_signal_handlers_block_by_func	(G_OBJECT (pd->real_host), G_CALLBACK (real_host_changed), pd);
+			gtk_entry_set_text (GTK_ENTRY (pd->real_host), str);
+			g_signal_handlers_unblock_by_func (G_OBJECT (pd->real_host), G_CALLBACK (real_host_changed), pd);
+		}
 
-	return vbox2;
+		if (str) g_free (str);
+	} else if (!strcmp (entry->key, "/apps/CDDB-Slave2/info")) {
+
+		info = gconf_client_get_int (client, "/apps/CDDB-Slave2/info", NULL);
+		switch (info) {
+			case CDDB_SEND_FAKE_INFO: 
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->no_info), TRUE);
+				break;
+
+			case CDDB_SEND_REAL_INFO:
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->real_info), TRUE);
+				break;
+
+			case CDDB_SEND_OTHER_INFO:
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->specific_info), TRUE);
+				break;
+
+			default:
+				break;
+		}
+	} else if (!strcmp (entry->key, "/apps/CDDB-Slave2/server-type")) {
+		info = gconf_client_get_int (client, "/apps/CDDB-Slave2/server-type", NULL);
+		
+		switch (info) {
+			case CDDB_ROUND_ROBIN:
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->round_robin), TRUE);
+				break;
+
+			case CDDB_OTHER_FREEDB:
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->other_freedb), TRUE);
+				break;
+
+			case CDDB_OTHER_SERVER:
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->other_server), TRUE);
+				break;
+
+			default:
+				break;
+		}
+	} else if (!strcmp (entry->key, "/apps/CDDB-Slave2/server")) {
+		str = gconf_client_get_string (client, "/apps/CDDB-Slave2/server", NULL);
+		entry_str = gtk_entry_get_text (GTK_ENTRY (pd->other_host));
+		
+		if (str != NULL && (strcmp (str, entry_str) != 0) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (pd->other_server))) {
+			g_signal_handlers_block_by_func	(G_OBJECT (pd->other_host), G_CALLBACK (other_host_changed), pd);
+			gtk_entry_set_text (GTK_ENTRY (pd->other_host), str);
+			g_signal_handlers_unblock_by_func (G_OBJECT (pd->other_host), G_CALLBACK (other_host_changed), pd);
+		}
+		
+		if (str) g_free (str);
+	} else if (!strcmp (entry->key, "/apps/CDDB-Slave2/port")) {
+		info = gconf_client_get_int (client, "/apps/CDDB-Slave2/port", NULL);
+		str = g_strdup_printf ("%d", info);
+		entry_str = gtk_entry_get_text (GTK_ENTRY (pd->other_port));
+		
+		if ((strcmp (str, entry_str) != 0) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (pd->other_server))) {
+			g_signal_handlers_block_by_func	(G_OBJECT (pd->other_port), G_CALLBACK (other_port_changed), pd);
+			gtk_entry_set_text (GTK_ENTRY (pd->other_port), str);
+			g_signal_handlers_unblock_by_func (G_OBJECT (pd->other_port), G_CALLBACK (other_port_changed), pd);
+		}
+		g_free (str);
+	}
 }
 
 static void
@@ -667,38 +769,41 @@ create_dialog (GtkWidget *window)
 {
 	PropertyDialog *pd;
 
-	GtkWidget *main_vbox;
 	GtkWidget *frame;
 	GtkWidget *align;
 	GtkWidget *vbox, *hbox, *hbox2, *hbox3;
 	GtkWidget *label, *sw;
 	GtkWidget *icon;
+	GtkWidget *notebook, *login_page, *server_page;
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *col;
 	GtkTreeSelection *selection;
-	
+
 	char *str;
 	int info = CDDB_SEND_FAKE_INFO;
 	int port;
-	
+
 	pd = g_new (PropertyDialog, 1);
 	pd->dialog = window;
 	g_signal_connect (G_OBJECT (window), "destroy",
 			  G_CALLBACK (destroy_window), pd);
 
-	main_vbox = gtk_vbox_new (FALSE, 0);
-	gtk_box_set_spacing (GTK_BOX (main_vbox), 18);
-	gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (window)->vbox), 2);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), main_vbox, TRUE, TRUE, 0);
-
 	/* Log on info */
-	frame = hig_category_new (main_vbox, _("Login Information"), FALSE, FALSE);
+	notebook = gtk_notebook_new ();
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox),notebook, TRUE, TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
+	login_page = gtk_vbox_new (FALSE, 0);
+	gtk_box_set_spacing (GTK_BOX (login_page), 18);
+	gtk_container_set_border_width (GTK_CONTAINER (login_page), 5);
+	
+	frame = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (login_page), frame, TRUE, TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER(frame), 5);
+
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 
 	info = gconf_client_get_int (client, "/apps/CDDB-Slave2/info", NULL);
-	g_print ("info: %d\n", info);
 	pd->no_info = gtk_radio_button_new_with_mnemonic (NULL, _("Sen_d no information"));
 	if (info == CDDB_SEND_FAKE_INFO) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->no_info), TRUE);
@@ -721,14 +826,14 @@ create_dialog (GtkWidget *window)
 	if (info == CDDB_SEND_OTHER_INFO) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->specific_info), TRUE);
 	}
-	
+
 	g_signal_connect (G_OBJECT (pd->specific_info), "toggled",
 			  G_CALLBACK (specific_info_toggled), pd);
 	gtk_box_pack_start (GTK_BOX (vbox), pd->specific_info, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-	
+
 	label = gtk_label_new ("    ");
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
@@ -738,7 +843,7 @@ create_dialog (GtkWidget *window)
 	if (info != CDDB_SEND_OTHER_INFO) {
 		gtk_widget_set_sensitive (pd->name_box, FALSE);
 	}
-	
+
 	gtk_box_pack_start (GTK_BOX (hbox), pd->name_box, TRUE, TRUE, 0);
 
 	align = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
@@ -751,38 +856,56 @@ create_dialog (GtkWidget *window)
 	pd->real_name = gtk_entry_new ();
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->real_name);
 	str = gconf_client_get_string (client, "/apps/CDDB-Slave2/name", NULL);
-	if (str != NULL) {
+	if (str != NULL && info == CDDB_SEND_OTHER_INFO) {
 		gtk_entry_set_text (GTK_ENTRY (pd->real_name), str);
 		g_free (str);
 	}
+	else if (info == CDDB_SEND_REAL_INFO) {
+		gtk_entry_set_text (GTK_ENTRY (pd->real_name),g_get_user_name());
+	}
+
 	g_signal_connect (G_OBJECT (pd->real_name), "changed",
 			  G_CALLBACK (real_name_changed), pd);
 	gtk_table_attach (GTK_TABLE (pd->name_box), pd->real_name,
 			  1, 2, 0, 1, GTK_FILL | GTK_EXPAND, GTK_FILL,
 			  0, 0);
-	
+
 	align = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
 	label = gtk_label_new_with_mnemonic (_("Hostna_me:"));
 	gtk_container_add (GTK_CONTAINER (align), label);
 	gtk_table_attach (GTK_TABLE (pd->name_box), align,
 			  0, 1, 1, 2, GTK_FILL, GTK_FILL,
 			  0, 0);
-	
+
 	pd->real_host = gtk_entry_new ();
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->real_host);
 	str = gconf_client_get_string (client, "/apps/CDDB-Slave2/hostname", NULL);
-	if (str != NULL) {
+	if (str != NULL && info == CDDB_SEND_OTHER_INFO) {
 		gtk_entry_set_text (GTK_ENTRY (pd->real_host), str);
 		g_free (str);
 	}
+	else if (info == CDDB_SEND_REAL_INFO) {
+		gtk_entry_set_text (GTK_ENTRY (pd->real_host),get_hostname());
+	}
+
 	g_signal_connect (G_OBJECT (pd->real_host), "changed",
 			  G_CALLBACK (real_host_changed), pd);
 	gtk_table_attach (GTK_TABLE (pd->name_box), pd->real_host,
 			  1, 2, 1, 2, GTK_FILL | GTK_EXPAND, GTK_FILL,
 			  0, 0);
+	
+	gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), 
+			  login_page, gtk_label_new (_("Login Information")), -1);
 
 	/* Server info */
-	frame = hig_category_new (main_vbox, _("Server"), TRUE, TRUE);
+	server_page = gtk_vbox_new (FALSE, 0);
+	gtk_box_set_spacing (GTK_BOX (server_page), 18);
+	gtk_container_set_border_width (GTK_CONTAINER (server_page), 5);
+
+	
+	frame = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (server_page), frame, TRUE, TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER(frame), 5);
 
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
@@ -801,10 +924,10 @@ create_dialog (GtkWidget *window)
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
-	
+
 	label = gtk_label_new ("    ");
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	
+
 	pd->freedb_box = gtk_vbox_new (FALSE, 6);
 	gtk_widget_set_sensitive (pd->freedb_box, FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), pd->freedb_box, TRUE, TRUE, 0);
@@ -816,7 +939,7 @@ create_dialog (GtkWidget *window)
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
 					     GTK_SHADOW_IN);
 	gtk_box_pack_start (GTK_BOX (pd->freedb_box), sw, TRUE, TRUE, 2);
-	
+
 	pd->model = make_tree_model ();
 	pd->freedb_server = gtk_tree_view_new_with_model (pd->model);
 	g_object_unref (pd->model);
@@ -824,7 +947,7 @@ create_dialog (GtkWidget *window)
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (pd->freedb_server));
 	g_signal_connect (G_OBJECT (selection), "changed",
 			  G_CALLBACK (server_selection_changed), pd);
-	
+
 	cell = gtk_cell_renderer_text_new ();
 	col = gtk_tree_view_column_new_with_attributes (_("Server"), cell,
 							"text", 0, NULL);
@@ -835,7 +958,7 @@ create_dialog (GtkWidget *window)
 	col = gtk_tree_view_column_new_with_attributes (_("Location"), cell,
 							"text", 2, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (pd->freedb_server), col);
-	
+
 	gtk_container_add (GTK_CONTAINER (sw), pd->freedb_server);
 
 	/* create the update server list button */
@@ -846,7 +969,7 @@ create_dialog (GtkWidget *window)
  			  G_CALLBACK (update_clicked), pd);
 
 	gtk_container_add (GTK_CONTAINER (align), pd->update);
- 	
+
 	gtk_box_pack_start (GTK_BOX (pd->freedb_box), align, FALSE, FALSE, 0);
 
 	/* ... and it's contents */
@@ -879,13 +1002,13 @@ create_dialog (GtkWidget *window)
 
 	hbox3 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (pd->other_box), hbox3, FALSE, FALSE, 0);
-	
+
 	label = gtk_label_new ("    ");
-	gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);	
+	gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
 
 	hbox2 = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (hbox3), hbox2, FALSE, FALSE, 0);
-	
+
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (hbox2), hbox, FALSE, FALSE, 0);
 	label = gtk_label_new_with_mnemonic (_("Hos_tname:"));
@@ -915,7 +1038,7 @@ create_dialog (GtkWidget *window)
 	str = g_strdup_printf ("%d", port);
 	gtk_entry_set_text (GTK_ENTRY (pd->other_port), str);
 	g_free (str);
-	
+
 	gtk_box_pack_start (GTK_BOX (hbox), pd->other_port, FALSE, FALSE, 0);
 
 	switch (info) {
@@ -934,6 +1057,14 @@ create_dialog (GtkWidget *window)
 	default:
 		break;
 	}
+
+	gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), server_page,
+				  gtk_label_new (_("Server")), -1);
+
+	/* Add Notify */
+	pd->notify_id =  gconf_client_notify_add (client,
+			"/apps/CDDB-Slave2", notify_cb,
+			pd, NULL, NULL);
 }
 
 static GdkPixbuf *
@@ -942,7 +1073,7 @@ pixbuf_from_file (const char *filename)
 	GdkPixbuf *pixbuf;
 	char *fullname;
 
-	fullname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+	fullname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
                    filename, TRUE, NULL);
 	g_return_val_if_fail (fullname != NULL, NULL);
 
@@ -951,19 +1082,20 @@ pixbuf_from_file (const char *filename)
 
 	return pixbuf;
 }
-	
+
 int
 main (int argc,
       char **argv)
 {
 	GtkWidget *dialog_win;
 	GdkPixbuf *pixbuf;
-	
+	GnomeProgram *program;
+
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init (argv[0], VERSION, LIBGNOMEUI_MODULE, argc, argv, NULL);
+	program = gnome_program_init (argv[0], VERSION, LIBGNOMEUI_MODULE, argc, argv, NULL);
 
 	client = gconf_client_get_default ();
 	gconf_client_add_dir (client, "/apps/CDDB-Slave2",
@@ -975,9 +1107,9 @@ main (int argc,
 						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 						  NULL);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog_win), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog_win), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog_win), 0);
 
-	gtk_window_set_default_size (GTK_WINDOW (dialog_win), 440, 570);
+	gtk_window_set_default_size (GTK_WINDOW (dialog_win), 440, 400);
 	create_dialog (dialog_win);
 
 	gtk_dialog_set_default_response(GTK_DIALOG (dialog_win), GTK_RESPONSE_CLOSE);
@@ -997,5 +1129,7 @@ main (int argc,
 
 	gtk_main ();
 
+	g_object_unref (program);
+
 	return 0;
 }
