@@ -29,6 +29,11 @@ G_BEGIN_DECLS
   (dest).frame = (src).frame; \
 }
 
+typedef enum {
+	GNOME_CDROM_DEVICE_STATIC,
+	GNOME_CDROM_DEVICE_TRANSIENT
+} GnomeCDRomDeviceLifetime;
+
 typedef enum {
 	GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 	GNOME_CDROM_ERROR_NOT_OPENED,
@@ -46,7 +51,10 @@ typedef enum _GnomeCDRomDriveStatus {
 	GNOME_CDROM_STATUS_OK,
 	GNOME_CDROM_STATUS_NO_DISC,
 	GNOME_CDROM_STATUS_TRAY_OPEN,
-	GNOME_CDROM_STATUS_DRIVE_NOT_READY
+	GNOME_CDROM_STATUS_DRIVE_NOT_READY,
+	GNOME_CDROM_STATUS_DATA_CD,
+	GNOME_CDROM_STATUS_NO_CDROM,
+	GNOME_CDROM_STATUS_EMPTY_DISC
 } GnomeCDRomDriveStatus;
 
 typedef enum _GnomeCDRomAudioStatus {
@@ -83,6 +91,7 @@ typedef struct _GnomeCDRomStatus {
 	int track;
 	GnomeCDRomMSF relative;
 	GnomeCDRomMSF absolute;
+	GnomeCDRomMSF length;
 	int volume;
 } GnomeCDRomStatus;
 
@@ -100,6 +109,7 @@ struct _GnomeCDRom {
 
 	int fd;
 
+	GnomeCDRomDeviceLifetime lifetime;
 	GnomeCDRomPrivate *priv;
 };
 
@@ -226,6 +236,7 @@ gboolean gnome_cdrom_set_device (GnomeCDRom *cdrom,
 GnomeCDRom *gnome_cdrom_construct  (GnomeCDRom      *cdrom,
 				    const char      *device,
 				    GnomeCDRomUpdate update,
+				    GnomeCDRomDeviceLifetime lifetime,
 				    GError         **error);
 gboolean    gnome_cdrom_open_dev   (GnomeCDRom      *cdrom,
 				    GError         **error);
