@@ -294,38 +294,22 @@ make_button_from_widget (GnomeCD *gcd,
 }
 
 static GtkWidget *
-make_button_from_stock (GnomeCD *gcd,
-			const char *stock,
-			GCallback func,
-			const char *tooltip, 
-			const char *shortname)
+make_button_from_stock     (GnomeCD *gcd,
+			    const char *stock,
+			    GCallback func,
+			    const char *tooltip, 
+			    const char *shortname)
 {
 	GtkWidget *pixmap;
 
-	pixmap = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_BUTTON);
+	if (gtk_icon_factory_lookup_default (stock))
+		pixmap = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_BUTTON);
+	else
+		pixmap = gtk_image_new_from_icon_name (stock, GTK_ICON_SIZE_BUTTON);
 
 	return make_button_from_widget (gcd, pixmap, func, tooltip, shortname);
 }
 
-static GdkPixbuf *
-pixbuf_from_file (const char *filename)
-{
-	GdkPixbuf *pixbuf;
-	char *fullname;
-
-	fullname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-                   filename, TRUE, NULL);
-	if (fullname == NULL) {
-		/* If the elegant way doesn't work, try and brute force it */
-		fullname = g_strconcat(GNOME_ICONDIR, "/", filename, NULL);
-	}
-
-	pixbuf = gdk_pixbuf_new_from_file (fullname, NULL);
-	g_free (fullname);
-
-	return pixbuf;
-}
-
 static void
 window_destroy_cb (GtkWidget *window,
 		   gpointer data)
@@ -420,22 +404,11 @@ make_popup_menu (GnomeCD *gcd, GdkEventButton *event, gboolean iconify)
 		        icon_name = menuitems[i].icon;
 		
 		if (icon_name != NULL) {
-	        	char *ext = strrchr (icon_name, '.');
-
-		        if (ext == NULL) 
+			if (gtk_icon_factory_lookup_default (icon_name))
 				image = gtk_image_new_from_stock (icon_name, GTK_ICON_SIZE_MENU);
-		        else {
-				char *fullname;
-				fullname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-				                                      icon_name, TRUE, NULL);
-				if (fullname != NULL) 
-					image = gtk_image_new_from_file (fullname);
-				else 
-       					image = NULL;
-        	       	       
-				g_free (fullname);
-		     	}
-        	}
+			else
+				image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
+		}
 		
 		if (image != NULL) {
 			gtk_widget_show (image);
@@ -504,7 +477,6 @@ static void
 set_volume (GnomeCD *gcd)
 {
 	GError *error = NULL;
-	GtkTooltips *volume_level_tooltip;
 	gchar *volume_level;
 	gint scaled_volume;
 	double volume;
@@ -581,8 +553,6 @@ init_player (const char *device_override)
 	GtkWidget *display_box;
 	GtkWidget *top_hbox, *button_hbox, *option_hbox;
 	GtkWidget *button;
-	GdkPixbuf *pixbuf;
-	GtkWidget *box;
 	GError *error = NULL;
 	GError *detailed_error = NULL;
 
@@ -681,15 +651,8 @@ init_player (const char *device_override)
 	gtk_window_set_title (GTK_WINDOW (gcd->window), _("CD Player"));
 	gtk_window_set_role (GTK_WINDOW (gcd->window), "gnome-cd-main-window");
 	gtk_window_set_default_size (GTK_WINDOW (gcd->window), 350, 129);
+	gtk_window_set_icon_name (GTK_WINDOW (gcd->window), "gnome-cd");
 	
-	pixbuf = pixbuf_from_file ("gnome-cd/cd.png");
-	if (pixbuf == NULL) {
-		g_warning ("Error finding gnome-cd/cd.png");
-	} else {
-		gtk_window_set_icon (GTK_WINDOW (gcd->window), pixbuf);
-		g_object_unref (G_OBJECT (pixbuf));
-	}
-
 	g_signal_connect (G_OBJECT (gcd->window), "destroy",
 			  G_CALLBACK (window_destroy_cb), gcd);
 	gcd->vbox = gtk_vbox_new (FALSE, 1);
@@ -758,10 +721,10 @@ init_player (const char *device_override)
 	option_hbox = gtk_hbox_new (FALSE, 2);
 
 	/* Create app controls */
-	button = make_button_from_stock (gcd, GTK_STOCK_PREFERENCES,
-					 G_CALLBACK(open_preferences),
-					 _("Open preferences"),
-					 _("Preferences"));
+	button = make_button_from_stock     (gcd, GTK_STOCK_PREFERENCES,
+					     G_CALLBACK(open_preferences),
+					     _("Open preferences"),
+					     _("Preferences"));
 	gtk_box_pack_start (GTK_BOX (option_hbox), button, FALSE, FALSE, 0);
 	gcd->properties_b = button;
 
@@ -773,10 +736,10 @@ init_player (const char *device_override)
 	gnome_cd_build_track_list_menu (gcd);
 	gtk_box_pack_start (GTK_BOX (option_hbox), gcd->tracks, TRUE, TRUE, 0);
 
-	button = make_button_from_stock (gcd, GTK_STOCK_INDEX,
-					 G_CALLBACK(open_track_editor),
-					 _("Open track editor"),
-					 _("Track editor"));
+	button = make_button_from_stock         (gcd, GTK_STOCK_INDEX,
+					     G_CALLBACK(open_track_editor),
+					     _("Open track editor"),
+					     _("Track editor"));
 	gtk_widget_set_sensitive (button, FALSE);
 	gtk_box_pack_start (GTK_BOX (option_hbox), button, FALSE, FALSE, 0);
 	gcd->trackeditor_b = button;
@@ -858,17 +821,8 @@ init_player (const char *device_override)
 void
 tray_icon_create (GnomeCD *gcd)
 {
-	GdkPixbuf *pixbuf;
-	GdkPixbuf *icon;
-	GtkWidget *box;
-
-	icon = pixbuf_from_file ("gnome-cd/cd.png");
-	pixbuf = gdk_pixbuf_scale_simple (icon, 16, 16, GDK_INTERP_BILINEAR);
-	g_object_unref (G_OBJECT (icon));
-
 	/* Tray icon */
-	gcd->tray = gtk_status_icon_new_from_pixbuf (pixbuf);
-	g_object_unref (G_OBJECT (pixbuf));
+	gcd->tray = gtk_status_icon_new_from_icon_name ("gnome-cd");
 
 	gtk_status_icon_set_tooltip (gcd->tray, _("CD Player"));
 
@@ -907,45 +861,6 @@ static void client_die(GnomeClient *client,
 	gtk_main_quit ();
 }
 
-static const char *items [] =
-{
-	GNOME_CD_EJECT
-};
-
-static void
-register_stock_icons (void)
-{
-	GtkIconFactory *factory;
-	int i;
-
-	factory = gtk_icon_factory_new ();
-	gtk_icon_factory_add_default (factory);
-
-	for (i = 0; i < (int) G_N_ELEMENTS (items); i++) {
-		GtkIconSet *icon_set;
-		GdkPixbuf *pixbuf;
-		char *filename, *fullname;
-
-		filename = g_strconcat ("gnome-cd/", items[i], ".png", NULL);
-		fullname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, filename, TRUE, NULL);
-		if (fullname == NULL) {
-			fullname = g_strconcat(GNOME_ICONDIR, "/", filename, NULL);
-		}
-		g_free (filename);
-
-		pixbuf = gdk_pixbuf_new_from_file (fullname, NULL);
-		g_free (fullname);
-
-		icon_set = gtk_icon_set_new_from_pixbuf (pixbuf);
-		gtk_icon_factory_add (factory, items[i], icon_set);
-		gtk_icon_set_unref (icon_set);
-
-		g_object_unref (G_OBJECT (pixbuf));
-	}
-
-	g_object_unref (G_OBJECT (factory));
-}
-
 static gboolean
 start_playing (GnomeCD *gcd)
 {
@@ -972,11 +887,13 @@ main (int argc, char *argv[])
 
 	GnomeCD *gcd;
 	GnomeClient *client;
-	GOptionGroup *group;
 	GOptionContext *ctx;
+	GnomeProgram *program;
 
 	free (malloc (8)); /* -lefence */
 
+	g_thread_init (NULL);
+
 	if (g_getenv ("GNOME_CD_DEBUG")) {
 		debug_mode = TRUE;
 	}
@@ -993,12 +910,11 @@ main (int argc, char *argv[])
 
 	g_option_context_add_main_entries (ctx, cd_goptions, GETTEXT_PACKAGE);
 
-	gnome_program_init ("gnome-cd", VERSION, LIBGNOMEUI_MODULE, 
-			    argc, argv, 
-			    GNOME_PARAM_GOPTION_CONTEXT, ctx,
-			    GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+	program = gnome_program_init ("gnome-cd", VERSION, LIBGNOMEUI_MODULE, 
+				      argc, argv, 
+				      GNOME_PARAM_GOPTION_CONTEXT, ctx,
+				      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
-	register_stock_icons ();
 	client = gnome_master_client ();
 	g_signal_connect (client, "save_yourself",
                          G_CALLBACK (save_session), (gpointer) argv[0]);
@@ -1007,6 +923,7 @@ main (int argc, char *argv[])
 	if (gcd == NULL) {
 		/* Stick a message box here? */
 		g_error (_("Cannot create player"));
+		g_object_unref (program);
 		exit (0);
 	}
 
@@ -1031,5 +948,8 @@ main (int argc, char *argv[])
 	setup_a11y_factory ();
 
 	bonobo_main ();
+
+	g_object_unref (program);
+
 	return 0;
 }
