@@ -98,9 +98,6 @@ static gboolean        gst_cdrom_next            (GnomeCDRom         * cdrom,
 static gboolean        gst_cdrom_back            (GnomeCDRom         * cdrom,
                                                   GError            ** error);
 
-static gboolean        gst_cdrom_update_tray_status (GstCDRom * cdrom,
-                                                     GError  ** error);
-
 static gboolean        gst_cdrom_get_cddb_data   (GnomeCDRom          * cdrom,
                                                   GnomeCDRomCDDBData ** data,
                                                   GError             ** error);
@@ -575,7 +572,23 @@ gst_cdrom_eos_msg (GstCDRom * cdrom, GstMessage * msg, GstBus * bus)
 
   GST_DEBUG ("received EOS %s", (was_last) ? "(last track)" : "");
 
-  if (was_last) {
+  if (was_last && GNOME_CDROM (cdrom)->playmode == GNOME_CDROM_SINGLE_TRACK) {
+    GnomeCDRomMSF start_msf, end_msf;
+    start_msf.minute = 0;
+    start_msf.second = 0;
+    start_msf.frame = 0;
+
+    end_msf.minute = 0;
+    end_msf.second = 0;
+    end_msf.frame = 0;
+
+    gst_cdrom_play (GNOME_CDROM (cdrom),
+		    cdrom->priv->status.track,
+		    &start_msf,
+		    cdrom->priv->status.track,
+		    &end_msf,
+		    NULL);
+  } else if (was_last) {
     gst_cdrom_set_playbin_state_to_null (cdrom);
     cdrom->priv->status.audio = GNOME_CDROM_AUDIO_COMPLETE;
   } else {
@@ -982,12 +995,6 @@ gst_cdrom_update_cd (GnomeCDRom * gnome_cdrom)
 */
 }
 
-static gboolean
-gst_cdrom_update_tray_status (GstCDRom * cdrom, GError ** error)
-{
-  return FALSE;
-}
-
 /* FIXME: do tray status checking */
 
 static gboolean
