@@ -50,7 +50,7 @@
 
 #include <gtk/gtkscrolledwindow.h>
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <gnome.h>
 
 #include <nautilus-burn-drive-selection.h>
@@ -150,7 +150,8 @@ do_theme_changed (GnomeCDPreferences *prefs,
 		prefs->gcd->theme = old_theme;
 	} else {
 		theme_change_widgets (prefs->gcd);
-		theme_free (old_theme);
+		if (old_theme != NULL)
+			theme_free (old_theme);
 	}
 }
 
@@ -170,73 +171,59 @@ static void
 restore_preferences (GnomeCDPreferences *prefs)
 {
 	GError *error = NULL;
+	GnomeCD *gcd = prefs->gcd;
 
 	/* Add the dir, cos we're getting all the stuff from it anyway */
-	gconf_client_add_dir (client, "/apps/gnome-cd",
+	gconf_client_add_dir (gcd->client, "/apps/gnome-cd",
 			      GCONF_CLIENT_PRELOAD_NONE, &error);
 	if (error != NULL) {
 		g_warning ("Error: %s", error->message);
 		error = NULL;
 	}
 	
-	prefs->device = gconf_client_get_string (client,
+	prefs->device = gconf_client_get_string (gcd->client,
 						 "/apps/gnome-cd/device", NULL);
 	if (prefs->device == NULL) {
 		g_warning ("GConf schemas are not correctly installed.");
 		prefs->device = g_strdup (default_cd_device);
 	}
 	
-	prefs->device_id = gconf_client_notify_add (client,
+	prefs->device_id = gconf_client_notify_add (gcd->client,
 						    "/apps/gnome-cd/device", device_changed,
 						    prefs, NULL, &error);
 	if (error != NULL) {
 		g_warning ("Error: %s", error->message);
 	}
 						    
-	prefs->start_play = gconf_client_get_bool (client,
+	prefs->start_play = gconf_client_get_bool (gcd->client,
 					     "/apps/gnome-cd/on-start-play",
 					      NULL);
-	prefs->start_id = gconf_client_notify_add (client,
+	prefs->start_id = gconf_client_notify_add (gcd->client,
 						   "/apps/gnome-cd/on-start-play",
 						   on_start_changed, prefs,
 						   NULL, NULL);
 	
-	prefs->stop_eject = gconf_client_get_bool (client,
+	prefs->stop_eject = gconf_client_get_bool (gcd->client,
 						   "/apps/gnome-cd/on-stop-eject",
 						   NULL);
-	prefs->stop_id = gconf_client_notify_add (client,
+	prefs->stop_id = gconf_client_notify_add (gcd->client,
 						  "/apps/gnome-cd/on-stop-eject",
 						  on_stop_changed, prefs,
 						  NULL, NULL);
 
-	prefs->theme_name = gconf_client_get_string (client,
+	prefs->theme_name = gconf_client_get_string (gcd->client,
 						     "/apps/gnome-cd/theme-name", NULL);
 	if (prefs->theme_name == NULL) {
 		g_warning ("GConf schemas are not correctly installed");
 		prefs->theme_name = g_strdup ("lcd");
 	}
 	
-	prefs->theme_id = gconf_client_notify_add (client,
+	prefs->theme_id = gconf_client_notify_add (gcd->client,
 						   "/apps/gnome-cd/theme-name",
 						   theme_changed, prefs,
 						   NULL, NULL);
 }
 
-void
-preferences_free (GnomeCDPreferences *prefs)
-{
-	g_free (prefs->device);
-	g_free (prefs->theme_name);
-
-	/* Remove the listeners */
-	gconf_client_notify_remove (client, prefs->device_id);
-	gconf_client_notify_remove (client, prefs->start_id);
-	gconf_client_notify_remove (client, prefs->stop_id);
-	gconf_client_notify_remove (client, prefs->theme_id);
-
-	g_free (prefs);
-}
-
 GnomeCDPreferences *
 preferences_new (GnomeCD *gcd)
 {
@@ -245,8 +232,6 @@ preferences_new (GnomeCD *gcd)
 	prefs = g_new0 (GnomeCDPreferences, 1);
 	prefs->gcd = gcd;
 
-	client = gconf_client_get_default ();
-	
 	restore_preferences (prefs);
 	
 	return prefs;
@@ -317,10 +302,12 @@ static void
 prefs_destroy_cb (GtkDialog *dialog,
 		  PropertyDialog *pd)
 {
-	gconf_client_notify_remove (client, pd->device_id);
-	gconf_client_notify_remove (client, pd->start_id);
-	gconf_client_notify_remove (client, pd->stop_id); 
-	gconf_client_notify_remove (client, pd->theme_id);
+	GnomeCD *gcd = pd->gcd;	
+	
+	gconf_client_notify_remove (gcd->client, pd->device_id);
+	gconf_client_notify_remove (gcd->client, pd->start_id);
+	gconf_client_notify_remove (gcd->client, pd->stop_id); 
+	gconf_client_notify_remove (gcd->client, pd->theme_id);
 	
 	g_free (pd);
 }
@@ -339,7 +326,7 @@ device_changed_cb (NautilusBurnDriveSelection *bcs,
 	    strcmp (device_path, pd->gcd->preferences->device) == 0)
 		return;
 	
-	gconf_client_set_string (client, "/apps/gnome-cd/device", device_path, NULL);
+	gconf_client_set_string (pd->gcd->client, "/apps/gnome-cd/device", device_path, NULL);
 
 	dummy = gnome_cdrom_new (device_path, GNOME_CDROM_UPDATE_NEVER, NULL);
 	g_object_unref (dummy);
@@ -349,7 +336,7 @@ static void
 start_play_toggled_cb (GtkToggleButton *tb,
 		       PropertyDialog *pd)
 {
-	gconf_client_set_bool (client, "/apps/gnome-cd/on-start-play",
+	gconf_client_set_bool (pd->gcd->client, "/apps/gnome-cd/on-start-play",
 			       gtk_toggle_button_get_active (tb), NULL);
 }
 
@@ -374,7 +361,7 @@ static void
 stop_open_toggled_cb (GtkToggleButton *tb,
 		      PropertyDialog *pd)
 {
-	gconf_client_set_bool (client, "/apps/gnome-cd/on-stop-eject",
+	gconf_client_set_bool (pd->gcd->client, "/apps/gnome-cd/on-stop-eject",
 			       gtk_toggle_button_get_active (tb), NULL);
 }
 
@@ -406,7 +393,7 @@ theme_selection_changed_cb (GtkTreeSelection *selection,
 		char *theme_name;
 
 		gtk_tree_model_get (model, &iter, 0, &theme_name, -1);
-		gconf_client_set_string (client, "/apps/gnome-cd/theme-name", theme_name, NULL);
+		gconf_client_set_string (pd->gcd->client, "/apps/gnome-cd/theme-name", theme_name, NULL);
 		g_free (theme_name);
 	}
 }
@@ -488,50 +475,6 @@ create_theme_model (PropertyDialog *pd,
 	return GTK_TREE_MODEL (store);
 }
 
-static void
-add_relation (AtkRelationSet *set,
-	      AtkRelationType type,
-	      AtkObject *target)
-{
-	AtkRelation *relation;
-
-	relation = atk_relation_set_get_relation_by_type (set, type);
-
-	if (relation != NULL) {
-		GPtrArray *array = atk_relation_get_target (relation);
-
-		g_ptr_array_remove (array, target);
-		g_ptr_array_add (array, target);
-	} else {
-		/* Relation hasn't been created yet */
-		relation = atk_relation_new (&target, 1, type);
-
-		atk_relation_set_add (set, relation);
-		g_object_unref (relation);
-	}
-}
-
-static void
-add_paired_relations (GtkWidget *target1,
-		      AtkRelationType target1_type,
-		      GtkWidget *target2,
-		      AtkRelationType target2_type)
-{
-	AtkObject *atk_target1;
-	AtkObject *atk_target2;
-	AtkRelationSet *set1;
-	AtkRelationSet *set2;
-
-	atk_target1 = gtk_widget_get_accessible (target1);
-	atk_target2 = gtk_widget_get_accessible (target2);
-
-	set1 = atk_object_ref_relation_set (atk_target1);
-	add_relation (set1, target1_type, atk_target2);
-
-	set2 = atk_object_ref_relation_set (atk_target2);
-	add_relation (set2, target2_type, atk_target1);
-}
-
 static void
 add_description (GtkWidget *widget, 
 		 const gchar *desc)
@@ -655,7 +598,7 @@ preferences_dialog_show (GnomeCD *gcd)
 			  G_CALLBACK (start_play_toggled_cb), pd);
 	gtk_box_pack_start (GTK_BOX (action_vbox), pd->start_play, FALSE, FALSE, 0);
 
-	pd->start_id = gconf_client_notify_add (client,
+	pd->start_id = gconf_client_notify_add (gcd->client,
 						"/apps/gnome-cd/on-start-play",
 						change_play_widget, pd, NULL, NULL);
 	
@@ -668,7 +611,7 @@ preferences_dialog_show (GnomeCD *gcd)
 			  G_CALLBACK (stop_open_toggled_cb), pd);
 	gtk_box_pack_start (GTK_BOX (action_vbox), pd->stop_open, FALSE, FALSE, 0);
 
-	pd->stop_id = gconf_client_notify_add (client,
+	pd->stop_id = gconf_client_notify_add (gcd->client,
 					       "/apps/gnome-cd/on-stop-eject",
 					       change_stop_widget, pd, NULL, NULL);
 	
@@ -727,7 +670,7 @@ preferences_dialog_show (GnomeCD *gcd)
 	gtk_container_add (GTK_CONTAINER (sw), pd->theme_list);
 	gtk_box_pack_start (GTK_BOX (hbox), sw, TRUE, TRUE, 0);
 
-	pd->theme_id = gconf_client_notify_add (client,
+	pd->theme_id = gconf_client_notify_add (gcd->client,
 						"/apps/gnome-cd/theme-name",
 						change_theme_selection_widget, pd, NULL, NULL);
 	gtk_widget_show_all (pd->window);
