@@ -26,6 +26,7 @@
 #define _ISOC99_SOURCE
 
 #include <math.h>
+#include <glib/gi18n.h>
 #include <gnome.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
@@ -185,9 +186,9 @@ get_scale (GnomeVolumeControlVolume *vol,
   gchar *accessible_name;
 
   adj = gtk_adjustment_new (volume,
-			    vol->track->min_volume,
-			    vol->track->max_volume,
-			    1.0, 1.0, 0.0);
+		vol->track->min_volume, vol->track->max_volume,
+		(vol->track->max_volume - vol->track->min_volume) / 100.0,
+		(vol->track->max_volume - vol->track->min_volume) / 10.0, 0.0);
   g_signal_connect (adj, "value_changed",
 		    G_CALLBACK (cb_volume_changed), vol);
   slider = gtk_vscale_new (GTK_ADJUSTMENT (adj));
