@@ -23,8 +23,10 @@
 #include "config.h"
 #endif
 
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gnome.h>
+#include <gconf/gconf-client.h>
 
 #include "keys.h"
 #include "preferences.h"
@@ -135,25 +137,34 @@ static GnomeUIInfo menu[] = {
 static void
 gnome_volume_control_window_init (GnomeVolumeControlWindow *win)
 {
+  int width, height;
+
   win->elements = NULL;
   win->element_menu = NULL;
   win->el = NULL;
   win->client = gconf_client_get_default ();
   win->prefs = NULL;
+  win->use_default_mixer = FALSE;
 
   /* init */
   gnome_app_construct (GNOME_APP (win),
 		       "gnome-volume-control", _("Volume Control"));
 
-  /* reasonable (...) default size */
-  gtk_widget_set_size_request (GTK_WIDGET (win), 500, -1);
+  /* To set the window according to previous geometry */
+  width = gconf_client_get_int (win->client,PREF_UI_WINDOW_WIDTH, NULL);
+  if (width < 250)
+    width = 250;
+  gconf_client_get_int (win->client,PREF_UI_WINDOW_HEIGHT, NULL);
+  if (height < 100)
+    height = -1;
+  gtk_window_set_default_size (GTK_WINDOW (win), width, height);
 }
 
 GtkWidget *
 gnome_volume_control_window_new (GList *elements)
 {
-  GConfValue *value;
-  const gchar *active_el_str = NULL, *cur_el_str, *cur_de_str;
+  gchar *cur_el_str, *cur_de_str;
+  gchar *active_el_str;
   GstElement *active_element;
   GList *item;
   GnomeVolumeControlWindow *win;
@@ -163,9 +174,8 @@ gnome_volume_control_window_new (GList *elements)
   gint count = 0, i;
   gchar *title;
 
-  /* default element to first */
   g_return_val_if_fail (elements != NULL, NULL);
-  active_element = elements->data;
+  active_element = NULL;
 
   /* window */
   win = g_object_new (GNOME_VOLUME_CONTROL_TYPE_WINDOW, NULL);
@@ -175,9 +185,12 @@ gnome_volume_control_window_new (GList *elements)
   /* menus, and the available elements in a submenu */
   win->element_menu = g_new (GnomeUIInfo, g_list_length (elements) + 1);
   for (count = 0, item = elements; item != NULL; item = item->next, count++) {
-    cur_el_str = g_object_get_data (item->data, "gnome-volume-control-name");
-    cur_de_str = g_strdup_printf (_("Change device to %s"), cur_el_str);
-    cur_el_str = g_strdup_printf ("_%d: %s", count, cur_el_str);
+    const gchar *tmp;
+
+    tmp = g_object_get_data (item->data, "gnome-volume-control-name");
+    cur_de_str = g_strdup_printf (_("Change device to %s"), tmp);
+    cur_el_str = g_strdup_printf ("_%d: %s", count, tmp);
+
     win->element_menu[count] = templ;
     win->element_menu[count].label = cur_el_str;
     win->element_menu[count].hint = cur_de_str;
@@ -192,19 +205,11 @@ gnome_volume_control_window_new (GList *elements)
   gnome_app_set_statusbar (app, bar);
   gnome_app_install_appbar_menu_hints (GNOME_APPBAR (bar), menu);
 
-  /* gconf */
-  gconf_client_add_dir (win->client, GNOME_VOLUME_CONTROL_KEY_DIR,
-			GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-  gconf_client_notify_add (win->client, GNOME_VOLUME_CONTROL_KEY_DIR,
-			   cb_gconf, win, NULL, NULL);
-
   /* get active element, if any (otherwise we use the default) */
-  if ((value = gconf_client_get (win->client,
-				 GNOME_VOLUME_CONTROL_KEY_ACTIVE_ELEMENT,
-				 NULL)) != NULL &&
-      value->type == GCONF_VALUE_STRING) {
-    active_el_str = gconf_value_get_string (value);
-
+  active_el_str = gconf_client_get_string (win->client,
+					   GNOME_VOLUME_CONTROL_KEY_ACTIVE_ELEMENT,
+					   NULL);
+  if (active_el_str != NULL && active_el_str != '\0') {
     for (count = 0, item = elements; item != NULL;
 	 item = item->next, count++) {
       cur_el_str = g_object_get_data (item->data, "gnome-volume-control-name");
@@ -213,12 +218,32 @@ gnome_volume_control_window_new (GList *elements)
         break;
       }
     }
-    if (!item)
+    g_free (active_el_str);
+    if (!item) {
       count = 0;
+      active_element = elements->data;
+      /* If there's a default but it doesn't match what we have available,
+       * reset the default */
+      gconf_client_set_string (win->client,
+      			       GNOME_VOLUME_CONTROL_KEY_ACTIVE_ELEMENT,
+      			       g_object_get_data (G_OBJECT (active_element),
+      			       			  "gnome-volume-control-name"),
+      			       NULL);
+    }
+    /* default element to first */
+    if (!active_element)
+      active_element = elements->data;
   } else {
     count = 0;
+    active_element = elements->data;
   }
 
+  /* gconf */
+  gconf_client_add_dir (win->client, GNOME_VOLUME_CONTROL_KEY_DIR,
+			GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
+  gconf_client_notify_add (win->client, GNOME_VOLUME_CONTROL_KEY_DIR,
+			   cb_gconf, win, NULL, NULL);
+
   /* window title and menu selection */
   title = g_strdup_printf (_("Volume Control: %s"),
 			   g_object_get_data (G_OBJECT (active_element),
@@ -230,6 +255,8 @@ gnome_volume_control_window_new (GList *elements)
     GTK_CHECK_MENU_ITEM (win->element_menu[count].widget)->active = TRUE;
   }
 
+  win->use_default_mixer = (active_el_str == NULL);
+
   /* add content for this element */
   gst_element_set_state (active_element, GST_STATE_READY);
   el = gnome_volume_control_element_new (active_element,
@@ -264,14 +291,7 @@ gnome_volume_control_window_dispose (GObject *object)
   if (win->elements) {
     const GList *item;
 
-    for (item = win->elements; item != NULL; item = item->next) {
-      GstElement *element = GST_ELEMENT (item->data);
-
-      gst_element_set_state (element, GST_STATE_NULL);
-      g_free (g_object_get_data (G_OBJECT (element),
-				 "gnome-volume-control-name"));
-      gst_object_unref (GST_OBJECT (element));
-    }
+    g_list_foreach (win->elements, (GFunc) g_object_unref, NULL);
     g_list_free (win->elements);
     win->elements = NULL;
   }
@@ -285,6 +305,7 @@ gnome_volume_control_window_dispose (GObject *object)
     gint i;
 
     for (i = 0; win->element_menu[i].widget != NULL; i++) {
+      g_free ((void *) win->element_menu[i].label);
       g_free ((void *) win->element_menu[i].hint);
     }
     g_free (win->element_menu);
@@ -313,6 +334,12 @@ cb_change (GtkWidget *widget,
       GConfValue *value;
       const gchar *label = win->element_menu[i].label;
 
+      if (win->use_default_mixer && (i == 0)) 
+	      /* we are selecting the default, ignore */
+	      return;
+
+      win->use_default_mixer = FALSE;
+
       /* skip mnemonic */
       while (*label != ':') label++; label++;
       while (*label == ' ') label++;
@@ -364,7 +391,6 @@ static void
 cb_about (GtkWidget *widget,
 	  gpointer   data)
 {
-  GtkWidget *about;
   const gchar *authors[] = { "Ronald Bultje <rbultje@ronald.bitfreak.net>",
 			     "Leif Johnson <leif@ambient.2y.net>",
 			     NULL };
@@ -376,15 +402,22 @@ cb_about (GtkWidget *widget,
 
   if (!strcmp (translators, "translator-credits"))
     translators = NULL;
-
-  about = gnome_about_new (_("Volume Control"),
-			   VERSION,
-			   "(c) 2003-2004 Ronald Bultje",
-			   _("A GNOME/GStreamer-based volume control application"),
-			   authors, documentors, translators,
-			   NULL);
-
-  gtk_widget_show (about);
+  
+  gtk_show_about_dialog (NULL,
+#if GTK_CHECK_VERSION (2, 12, 0)
+			 "program-name",
+#else
+			 "name",
+#endif
+			 _("Volume Control"),
+			 "version", VERSION,
+			 "copyright", "(c) 2003-2004 Ronald Bultje",
+			 "comments", _("A GNOME/GStreamer-based volume control application"),
+			 "authors", authors,
+			 "documenters", documentors,
+			 "translator-credits", translators,
+			 "logo-icon-name", "multimedia-volume-control",
+			 NULL);
 }
 
 /*
