@@ -1,3 +1,24 @@
+/* audio-profile.c: */
+
+/*
+ * Copyright (C) 2003 Thomas Vander Stichele
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <string.h>
 #include <gst/gst.h>
 
@@ -1034,7 +1055,7 @@ gm_audio_profile_create (const char  *name,
 
   gconf_client_set_string (conf,
                            key,
-                           _("wav"),
+                           "wav",
                            &err);
   if (err != NULL) g_print ("ERROR: msg: %s\n", err->message);
   BAIL_OUT_CHECK ();
